@@ -14,20 +14,20 @@ CRANpkg <- function(pkg){
 library(ggplot2)
 library(ggstar)
 
-## ---- fig.width=7, fig.height=6, fig.align="center", dev="svg", starshapes----
+## ---- fig.width=7, fig.height=6, fig.align="center", starshapes---------------
 p1 <- show_starshapes()
 p1
 
-## ---- fig.width=6, fig.height=5, fig.align="center", dev="svg", sizeshape-----
+## ---- fig.width=6, fig.height=5, fig.align="center",  sizeshape---------------
 library(ggplot2)
 library(ggstar)
 p2 <- ggplot(data=iris, aes(x=Sepal.Width,y=Sepal.Length)) + 
-      geom_star(aes(starshape=Species, color=Species), size=2.5) +
+      geom_star(aes(starshape=Species, fill=Species), size=2.5) +
       scale_fill_manual(values=c("#E41A1C", "#377EB8", "#4DAF4A")) +
       theme(legend.spacing.y = unit(0.02, "cm"))
 p2
 
-## ---- fig.width=6, fig.height=5.2, fig.align="center", dev="svg", polarcoord----
+## ---- fig.width=6, fig.height=5.2, fig.align="center", polarcoord-------------
 p3 <- ggplot(data=mtcars, aes(x=wt, y=mpg)) +
       geom_star(aes(fill=cyl), size=2.5) +
       scale_fill_gradient(low="blue", high="red") +
